<?php

/*************************************************************************
 * Premium Page  - XenConcept (c) 2017
 * All Rights Reserved.
 **************************************************************************
 * This file is subject to the terms and conditions defined in the Licence
 * Agreement available at Try it like it buy it :)
 *************************************************************************/

namespace XenConcept\PremiumPage\Admin\Controller;

use XF\Admin\Controller\AbstractController;
use XF\Mvc\ParameterBag;

class Column extends AbstractController
{

    public function actionIndex()
    {
        $columnRepo = $this->getColumnRepo();
        $columnFinder = $columnRepo->findColumnForList();

        $viewParams = [
            'columns' => $columnFinder->fetch()
        ];

        return $this->view('XenConcept\PremiumPage:Column\List', 'xc_premium_page_column_list', $viewParams);
    }

    protected function columnAddEdit(\XenConcept\PremiumPage\Entity\Column $column)
    {
        $serviceRepo = $this->getServiceRepo();
        $services    = $serviceRepo->findServicesForList()->fetch();

        $viewParams = [
            'services' => $services,
            'column'   => $column,
            'userGroups' => $this->getColumnRepo()->getUpgradeTitlePairs()
        ];

        return $this->view('XenConcept\PremiumPage:Column\Edit', 'xc_premium_page_column_edit', $viewParams);
    }

    public function actionAdd()
    {
        $column = $this->em()->create('XenConcept\PremiumPage:Column');

        return $this->columnAddEdit($column);
    }

    public function actionEdit(ParameterBag $params)
    {
        $column = $this->assertColumnExists($params->column_id);

        return $this->columnAddEdit($column);
    }

    protected function columnSaveProcess(\XenConcept\PremiumPage\Entity\Column $column)
    {
        $form = $this->formAction();

        $input = $this->filter([
            'title'    => 'str',
            'price'    => 'float',
            'currency' => 'str',
            'header_description' => 'str',
            'footer_description' => 'str',
            'title_button_purchase' => 'str',
            'user_group_id' => 'int',
            'external_link_button_purchase' => 'str'
        ]);

        $serviceParams = $this->filter('service_params', 'array');
        $services      = $this->getServiceRepo()->findServicesForList()->fetch();

        $errors = [];

        foreach ($services AS $serviceId => $service)
        {
            if ($serviceParams[$serviceId]['method_use'] == 'icon')
            {
                if (empty($serviceParams[$serviceId]['icon']))
                {
                    $errors[] = \XF::phrase('xc_premium_page_you_must_complete_the_x_service', ['title' => $service->title]);
                }
            }
            else
            {
                if (empty($serviceParams[$serviceId]['text']))
                {
                    $errors[] = \XF::phrase('xc_premium_page_you_must_complete_the_x_service', ['title' => $service->title]);
                }
            }
        }

        if ($errors)
        {
            $form->logErrors($errors);
        }

        $input['service_params'] = $serviceParams;

        $form->basicEntitySave($column, $input);

        return $form;
    }

    public function actionSave(ParameterBag $params)
    {
        if ($params['column_id'])
        {
            $column = $this->assertColumnExists($params['column_id']);
        }
        else
        {
            $column = $this->em()->create('XenConcept\PremiumPage:Column');
        }

        $this->columnSaveProcess($column)->run();

        return $this->redirect($this->buildLink('premium-page/columns'));
    }

    public function actionDelete(ParameterBag $params)
    {
        $column = $this->assertColumnExists($params['column_id']);

        if ($this->isPost())
        {
            $column->delete();
            return $this->redirect($this->buildLink('premium-page/columns'));
        }
        else
        {
            $viewParams = [
                'column' => $column
            ];
            return $this->view('XenConcept\PremiumPage:Column\Delete', 'xc_premium_page_column_delete', $viewParams);
        }
    }

    /**
     * @param string $id
     * @param array|string|null $with
     * @param null|string $phraseKey
     *
     * @return \XenConcept\PremiumPage\Entity\Column
     */
    protected function assertColumnExists($id, $with = null, $phraseKey = null)
    {
        return $this->assertRecordExists('XenConcept\PremiumPage:Column', $id, $with, $phraseKey);
    }

    /**
     * @return \XenConcept\PremiumPage\Repository\Column
     */
    protected function getColumnRepo()
    {
        return $this->repository('XenConcept\PremiumPage:Column');
    }

    /**
     * @return \XenConcept\PremiumPage\Repository\Service
     */
    protected function getServiceRepo()
    {
        return $this->repository('XenConcept\PremiumPage:Service');
    }
}