<?php

/*************************************************************************
 * Premium Page  - XenConcept (c) 2017
 * All Rights Reserved.
 **************************************************************************
 * This file is subject to the terms and conditions defined in the Licence
 * Agreement available at Try it like it buy it :)
 *************************************************************************/

namespace XenConcept\PremiumPage\Admin\Controller;

use XF\Admin\Controller\AbstractController;
use XF\Mvc\ParameterBag;

class Service extends AbstractController
{

    public function actionIndex()
    {
        $serviceRepo = $this->getServiceRepo();
        $serviceFinder = $serviceRepo->findServicesForList();

        $viewParams = [
            'services' => $serviceFinder->fetch(),
        ];

        return $this->view('XenConcept\PremiumPage:Service\List', 'xc_premium_page_list_service', $viewParams);
    }

    protected function serviceAddEdit(\XenConcept\PremiumPage\Entity\Service $service)
    {
        $viewParams = [
            'service' => $service
        ];

        return $this->view('XenConcept\PremiumPage:Service\Edit', 'xc_premium_page_edit_service', $viewParams);
    }

    public function actionAdd()
    {
        $service = $this->em()->create('XenConcept\PremiumPage:Service');
        return $this->serviceAddEdit($service);
    }

    public function actionEdit(ParameterBag $params)
    {
        $service = $this->assertServiceExists($params['service_id']);

        return $this->serviceAddEdit($service);
    }

    protected function serviceSaveProcess(\XenConcept\PremiumPage\Entity\Service $service)
    {
        $form = $this->formAction();

        $input = $this->filter([
            'title' => 'str',
            'tooltip' => 'str',
            'display_order' => 'uint'
        ]);

        $form->basicEntitySave($service, $input);

        return $form;
    }

    public function actionSave(ParameterBag $params)
    {
        $this->assertPostOnly();

        if ($params['service_id'])
        {
            $service = $this->assertServiceExists($params['service_id']);
        }
        else
        {
            $service = $this->em()->create('XenConcept\PremiumPage:Service');
        }

        $this->serviceSaveProcess($service)->run();

        return $this->redirect($this->buildLink('premium-page/services'));
    }

    public function actionDelete(ParameterBag $params)
    {
        $service = $this->assertServiceExists($params['service_id']);

        if ($this->isPost())
        {
            $service->delete();
            return $this->redirect($this->buildLink('premium-page/services'));
        }
        else
        {
            $viewParams = [
                'service' => $service
            ];
            return $this->view('XenConcept\PremiumPage:Service\Delete', 'xc_premium_page_delete_service', $viewParams);
        }
    }


    /**
     * @param string $id
     * @param array|string|null $with
     * @param null|string $phraseKey
     *
     * @return \XenConcept\PremiumPage\Entity\Service
     */
    protected function assertServiceExists($id, $with = null, $phraseKey = null)
    {
        return $this->assertRecordExists('XenConcept\PremiumPage:Service', $id, $with, $phraseKey);
    }


    /**
     * @return \XenConcept\PremiumPage\Repository\Service
     */
    protected function getServiceRepo()
    {
        return $this->repository('XenConcept\PremiumPage:Service');
    }

}