<?php

/*************************************************************************
 * Premium Page  - XenConcept (c) 2017
 * All Rights Reserved.
 **************************************************************************
 * This file is subject to the terms and conditions defined in the Licence
 * Agreement available at Try it like it buy it :)
 *************************************************************************/

namespace XenConcept\PremiumPage\Entity;

use XF\Mvc\Entity\Entity;
use XF\Mvc\Entity\Structure;

/**
 * COLUMNS
 * @property int|null column_id
 * @property string title
 * @property int price
 * @property string currency
 * @property string header_description
 * @property array service_params
 * @property string footer_description
 * @property string title_button_purchase
 * @property int user_group_id
 * @property string external_link_button_purchase
 */
class Column extends Entity
{

    public static function getStructure(Structure $structure)
    {
        $structure->table      = 'xc_premium_page_column';
        $structure->shortName  = 'XenConcept\PremiumPage:Column';
        $structure->primaryKey = 'column_id';
        $structure->columns = [
            'column_id' => ['type' => self::UINT, 'autoIncrement' => true, 'nullable' => true],
            'title' => ['type' => self::STR, 'maxLength' => 100,
                'required' => 'please_enter_valid_title',
                'censor' => true
            ],
            'price' => ['type' => self::UINT, 'default' => 0, 'max' => 99999999, 'min' => 0],
            'currency' => ['type' => self::STR, 'default' => '', 'maxLength' => 3],
            'header_description' => ['type' => self::STR, 'maxLength' => 100,
                'censor' => true
            ],
            'service_params' => ['type' => self::SERIALIZED_ARRAY, 'default' => []],
            'footer_description' => ['type' => self::STR, 'maxLength' => 100,
                'censor' => true
            ],
            'title_button_purchase' => ['type' => self::STR, 'maxLength' => 100],
            'user_group_id' => ['type' => self::UINT, 'default' => 0],
            'external_link_button_purchase' => ['type' => self::STR, 'maxLength' => 100,],
        ];
        $structure->getters = [
        ];
        $structure->relations = [
            'UserUpgrade' => [
                'entity' => 'XF:UserUpgrade',
                'type' => self::TO_ONE,
                'conditions' => 'user_group_id',
                'primary' => true
            ]
        ];

        return $structure;
    }

}